==> laravel-micro.js-1.1.3.tgz: package/README.md <==
![LaravelMicro.js](https://bayareawebpro.github.io/laravel-micro.js/logo.svg)

# `npm i laravel-micro.js`

[Documentation](https://bayareawebpro.github.io/laravel-micro.js/)

**A Laravel style frontend framework that works with your UI framework of choice.**

LaravelMicro.js is an IOC Container, Service Locator Pattern and Middleware Pipeline for your 
Laravel Frontend. It provides true dependency injection and a familiar design that encourages 
you to use object oriented principles in your client-side application.  It includes a DotSyntax 
Object Repository and Validator Service making it easy to work with data provided by 
Laravel Responses.

---

![CI](https://github.com/bayareawebpro/laravel-micro.js/workflows/ci/badge.svg)
![Coverage](https://img.shields.io/badge/Coverage-99-brightgreen.svg)
![License](https://img.shields.io/badge/License-MIT-brightgreen.svg)
![Dependencies](https://img.shields.io/badge/Dependencies-none-brightgreen.svg)
![DevDependencies](https://img.shields.io/badge/DevDependencies-latest-brightgreen.svg)
![Version](https://img.shields.io/badge/Version-1.x-blue.svg)

> This is a community project and not an official Laravel package. 
---

### Features
Compatible with Reactive Frameworks like Vue.js and React.

* Container
* Dependency Injection
* Router Integration
* Service Providers
* Error Handling
* Lazy Loading
* Middleware
* Repository
* Validator
* Mixins

> More Packages: https://github.com/bayareawebpro/laravel-micro.js/wiki/Other-Packages
--- 
#### Contribute
If your interesting in contributing to this project, please do.

> Test suite provided by Jest.

--- 

#### Dev Latest 
For playing with latest pre-release version.
```json
"devDependencies": {
    "laravel-micro.js": "git://github.com/bayareawebpro/laravel-micro.js.git"
}
```

==> laravel-micro.js-1.2.0.tgz: package/README.md <==
![LaravelMicro.js](https://bayareawebpro.github.io/laravel-micro.js/logo.svg)

# `npm i laravel-micro.js`

- [Documentation](https://bayareawebpro.github.io/laravel-micro.js/)
- [Project Starter](https://github.com/bayareawebpro/laravel-micro-spa-boilerplate)

**A Laravel style frontend framework that works with your UI framework of choice.**

LaravelMicro.js is an IOC Container, Service Locator Pattern and Middleware Pipeline for your 
Laravel Frontend. It provides true dependency injection, and a familiar design that encourages 
you to use object oriented principles in your client-side application.  It includes a DotSyntax 
Object Repository and Validator Service making it easy to work with data provided by 
Laravel Responses.


---

![CI](https://github.com/bayareawebpro/laravel-micro.js/workflows/ci/badge.svg)
![Coverage](https://codecov.io/gh/bayareawebpro/laravel-dom-pipeline/branch/master/graph/badge.svg)
![License](https://img.shields.io/badge/License-MIT-brightgreen.svg)
![Dependencies](https://img.shields.io/badge/Dependencies-none-brightgreen.svg)
![DevDependencies](https://img.shields.io/badge/DevDependencies-latest-brightgreen.svg)
![Version](https://img.shields.io/badge/Version-1.x-blue.svg)

> This is a community project and not an official Laravel package. 
---

### Features
Compatible with Reactive Frameworks like Vue.js and React.

* IOC Container
* Dependency Injection
* Router Integration
* Service Providers
* Error Handling
* Lazy Loading
* Middleware
* Repository
* Validator
* Mixins

> More Packages: https://github.com/bayareawebpro/laravel-micro.js/wiki/Other-Packages

--- 
#### Contribute
If your interesting in contributing to this project, please do.

> Test suite provided by Jest.

--- 

#### Dev Latest 
For playing with latest pre-release version.
```json
"devDependencies": {
    "laravel-micro.js": "git://github.com/bayareawebpro/laravel-micro.js.git"
}
```
